@@ -2,7 +2,7 @@
  *  calc_basic.c - arithmetic precedence handling and computing in basic 
  *			calculator mode.
  *	part of galculator
- *  	(c) 2002-2013 Simon Flöry (simon.floery@rechenraum.com)
+ *  	(c) 2002-2014 Simon Flöry (simon.floery@rechenraum.com)
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -341,6 +341,7 @@ static s_alg_stack *alg_stack_new (s_cb_token this_token)
 	new_stack->number = NULL;
 	new_stack->operation = NULL;
 	new_stack->size = 0;
+	
 	return new_stack;	
 }
 
@@ -392,9 +393,9 @@ static G_REAL alg_stack_pool (s_alg_stack *stack)
 
 static void alg_stack_free (s_alg_stack *stack)
 {
-	if (!stack) {
-		if (!stack->number) free (stack->number);
-		if (!stack->operation) free (stack->operation);
+	if (stack) {
+		if (stack->number) free (stack->number);
+		if (stack->operation) free (stack->operation);
 		free (stack);
 	}
 }
@@ -436,6 +437,8 @@ G_REAL alg_add_token (ALG_OBJECT **alg, s_cb_token this_token)
 		if (this_token.func != NULL)
 			return_value = this_token.func(return_value);
 		alg_stack_free (current_stack);
+		/* simon, 20140219 */
+		current_stack = NULL;
 		*alg = g_slist_delete_link (*alg, *alg);
 		break;
 	case '=':
@@ -477,7 +480,7 @@ ALG_OBJECT *alg_init (int debug_level)
 
 void alg_free (ALG_OBJECT *alg)
 {
-	if (!alg) {
+	if (alg) {
 		g_slist_foreach (alg, alg_stack_free_gfunc, NULL);
 		g_slist_free (alg);
 		alg = NULL;
