@@ -1,7 +1,7 @@
 /*
  *  callbacks.c - functions to handle GUI events.
  *    part of galculator
- *      (c) 2002-2013 Simon Flöry (simon.floery@rechenraum.com)
+ *      (c) 2002-2014 Simon Flöry (simon.floery@rechenraum.com)
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -371,6 +371,8 @@ on_rpn_toggled                       (GtkMenuItem     *menuitem,
     
     set_widget_visibility (view_xml, "formula_entry_hbox", FALSE);
     alg_free(main_alg);
+    /* 20140219, simon */
+    main_alg = NULL;
     all_clear();
     ui_button_set_rpn();
     /* stack is created by all_clear */
@@ -603,8 +605,10 @@ on_paste_activate (GtkMenuItem     *menuitem,
     if (cp_text) {
         if ((formula_entry = formula_entry_is_active_no_toplevel_check ()) != NULL) {
             gtk_editable_paste_clipboard((GtkEditable *)formula_entry);
-        }
-        else display_result_feed (cp_text, current_status.number);
+        } else {
+			rpn_stack_lift();
+			display_result_feed (cp_text, current_status.number);
+		}
         g_free (cp_text);
     }
 }
@@ -831,7 +835,7 @@ on_show_menubar1_toggled              (GtkMenuItem     *menuitem,
 #ifdef WITH_HILDON
     set_widget_visibility (main_window_xml, "main_menu", prefs.show_menu);
 #else
-     set_widget_visibility (main_window_xml, "menubar", prefs.show_menu);
+	set_widget_visibility (main_window_xml, "menubar", prefs.show_menu);
 #endif
 
     /* in case this cb is called by the right button mouse click menu */
