@@ -1,7 +1,7 @@
 /*
  *  general_functions.c - this and that.
  *	part of galculator
- *  	(c) 2002-2013 Simon Flöry (simon.floery@rechenraum.com)
+ *  	(c) 2002-2014 Simon Flöry (simon.floery@rechenraum.com)
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -103,6 +103,8 @@ void all_clear ()
 			break;
 		case CS_FORMULA:
 			alg_free(main_alg);
+			/* 20140219, simon */
+			main_alg = NULL;
 			rpn_free();
 			display_stack_remove();
 			break;
@@ -323,6 +325,10 @@ void apply_preferences (s_preferences prefs)
 
     menu_item = GTK_WIDGET(gtk_builder_get_object (main_window_xml, "show_menubar1"));
 	gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM(menu_item), prefs.show_menu);
+	/* If set_active does not toggle the current setting, than no callback gets
+	 * called and the menu bar might be in a wrong state.
+	 */
+	gtk_check_menu_item_toggled (GTK_CHECK_MENU_ITEM(menu_item));
 
 	switch (prefs.mode) {
 	case BASIC_MODE:
